@@ -71,7 +71,7 @@ type Reference struct {
 // Dependencies represents references to external dependencies
 type Dependencies struct {
 	Fs         afero.Fs
-	HttpClient *resty.Client
+	HttpClient *resty.Client //nolint:golint,stylecheck,revive
 }
 
 // Lot represents a cost basis lot
@@ -205,6 +205,8 @@ type QuoteSource int
 const (
 	QuoteSourceYahoo QuoteSource = iota
 	QuoteSourceUserDefined
+	QuoteSourceCoingecko
+	QuoteSourceUnknown
 )
 
 // AssetQuote represents a price quote and related attributes for a single security
