@@ -99,7 +99,7 @@ func transformResponseQuote(responseQuote ResponseQuote) c.AssetQuote {
 		return assetQuote
 	}
 
-	if responseQuote.MarketState == "POST" && responseQuote.PostMarketPrice == 0.0 {
+	if responseQuote.MarketState == "POSTPOST" && responseQuote.PostMarketPrice == 0.0 {
 		assetQuote.Exchange.IsRegularTradingSession = false
 
 		return assetQuote
@@ -112,7 +112,7 @@ func transformResponseQuote(responseQuote ResponseQuote) c.AssetQuote {
 		return assetQuote
 	}
 
-	if responseQuote.MarketState == "POST" {
+	if responseQuote.MarketState == "POSTPOST" {
 		assetQuote.QuotePrice.Price = responseQuote.PostMarketPrice
 		assetQuote.QuotePrice.Change = (responseQuote.PostMarketChange + responseQuote.RegularMarketChange)
 		assetQuote.QuotePrice.ChangePercent = responseQuote.PostMarketChangePercent + responseQuote.RegularMarketChangePercent
@@ -162,8 +162,11 @@ func transformResponseQuotes(responseQuotes []ResponseQuote) []c.AssetQuote {
 func GetAssetQuotes(client resty.Client, symbols []string) func() []c.AssetQuote {
 	return func() []c.AssetQuote {
 		symbolsString := strings.Join(symbols, ",")
-		url := fmt.Sprintf("https://query1.finance.yahoo.com/v7/finance/quote?lang=en-US&region=US&corsDomain=finance.yahoo.com&symbols=%s", symbolsString)
+		url := fmt.Sprintf("https://query1.finance.yahoo.com/v7/finance/quote?fields=shortName,regularMarketChange,regularMarketChangePercent,regularMarketPrice,regularMarketPreviousClose,regularMarketOpen,regularMarketDayRange,regularMarketDayHigh,regularMarketDayLow,regularMarketVolume,postMarketChange,postMarketChangePercent,postMarketPrice,preMarketChange,preMarketChangePercent,preMarketPrice,fiftyTwoWeekHigh,fiftyTwoWeekLow,marketCap&region=US&lang=en-US&symbols=%s", symbolsString)
 		res, _ := client.R().
+			SetHeader("Host", "query1.finance.yahoo.com").
+			SetHeader("accept", "*/*").
+			SetHeader("user-agent", "curl/7.68.0").
 			SetResult(Response{}).
 			Get(url)
 
