@@ -2,6 +2,7 @@ package http
 
 import (
 	"bytes"
+	"errors"
 	"html/template"
 	"net/http"
 
@@ -33,10 +34,11 @@ func MockResponse(responseParameters ResponseParameters) {
 	t, _ := template.New("response").Parse(responseTemplate)
 	//nolint:errcheck
 	t.Execute(&responseBytes, responseParameters)
-	responseURL := "https://query1.finance.yahoo.com/v7/finance/quote?lang=en-US&region=US&corsDomain=finance.yahoo.com&fields=regularMarketPrice,currency&symbols=" + responseParameters.Symbol
-	httpmock.RegisterResponder("GET", responseURL, func(req *http.Request) (*http.Response, error) {
+	responseUrl := "https://query1.finance.yahoo.com/v7/finance/quote?lang=en-US&region=US&corsDomain=finance.yahoo.com&fields=regularMarketPrice,currency&symbols=" + responseParameters.Symbol //nolint:golint,stylecheck,revive
+	httpmock.RegisterResponder("GET", responseUrl, func(req *http.Request) (*http.Response, error) {
 		resp := httpmock.NewStringResponse(200, responseBytes.String())
 		resp.Header.Set("Content-Type", "application/json")
+
 		return resp, nil
 	})
 }
@@ -55,14 +57,22 @@ func MockResponseCurrency() {
 			"error": null
 		}
 	}`
-	responseURL := `https://query1.finance.yahoo.com/v7/finance/quote`
-	httpmock.RegisterResponder("GET", responseURL, func(req *http.Request) (*http.Response, error) {
+	responseUrl := `https://query1.finance.yahoo.com/v7/finance/quote` //nolint:golint,stylecheck,revive
+	httpmock.RegisterResponder("GET", responseUrl, func(req *http.Request) (*http.Response, error) {
 		resp := httpmock.NewStringResponse(200, response)
 		resp.Header.Set("Content-Type", "application/json")
+
 		return resp, nil
 	})
 }
 
+func MockResponseCurrencyError() {
+	responseUrl := "https://query1.finance.yahoo.com/v7/finance/quote" //nolint:golint,stylecheck,revive
+	httpmock.RegisterResponder("GET", responseUrl, func(req *http.Request) (*http.Response, error) {
+		return &http.Response{}, errors.New("error getting currencies") //nolint:goerr113
+	})
+}
+
 func MockResponseYahooQuotes() {
 	response := `{
 		"quoteResponse": {
@@ -115,10 +125,38 @@ func MockResponseYahooQuotes() {
 			"error": null
 		}
 	}`
-	responseURL := "https://query1.finance.yahoo.com/v7/finance/quote?lang=en-US&region=US&corsDomain=finance.yahoo.com&symbols=GOOG,RBLX"
-	httpmock.RegisterResponder("GET", responseURL, func(req *http.Request) (*http.Response, error) {
+	responseUrl := "https://query1.finance.yahoo.com/v7/finance/quote?lang=en-US&region=US&corsDomain=finance.yahoo.com&symbols=GOOG,RBLX" //nolint:golint,stylecheck,revive
+	httpmock.RegisterResponder("GET", responseUrl, func(req *http.Request) (*http.Response, error) {
 		resp := httpmock.NewStringResponse(200, response)
 		resp.Header.Set("Content-Type", "application/json")
+
 		return resp, nil
 	})
 }
+
+func MockTickerSymbols() {
+	responseFixture := `"ADA.X","cardano","cg"
+"ALGO.X","algorand","cg"
+"BTC.X","bitcoin","cg"
+"ETH.X","ethereum","cg"
+"DOGE.X","dogecoin","cg"
+"DOT.X","polkadot","cg"
+"SOL.X","solana","cg"
+"USDC.X","usd-coin","cg"
+"XRP.X","ripple","cg"
+`
+	responseUrl := "https://raw.githubusercontent.com/achannarasappa/ticker-static/master/symbols.csv" //nolint:golint,stylecheck,revive
+	httpmock.RegisterResponder("GET", responseUrl, func(req *http.Request) (*http.Response, error) {
+		resp := httpmock.NewStringResponse(200, responseFixture)
+		resp.Header.Set("Content-Type", "text/plain; charset=utf-8")
+
+		return resp, nil
+	})
+}
+
+func MockTickerSymbolsError() {
+	responseUrl := "https://raw.githubusercontent.com/achannarasappa/ticker-static/master/symbols.csv" //nolint:golint,stylecheck,revive
+	httpmock.RegisterResponder("GET", responseUrl, func(req *http.Request) (*http.Response, error) {
+		return &http.Response{}, errors.New("error getting ticker symbols") //nolint:goerr113
+	})
+}
